==> jc-1.4.0.tar.gz: java/beans/Expression.h <==
// public class java.beans.Expression

// class file dependencies
// @dep_class 3e0727273db17f2 java_beans_Expression
// @dep_class 98ab29a738188935 java_beans_Statement
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_beans_Statement

#include "java/beans/Statement.h"

#ifndef _JC_java_beans_Expression_H_
#define _JC_java_beans_Expression_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_beans_Expression$sub_refs	_jc_java_beans_Expression$sub_refs;
typedef struct _jc_java_beans_Expression$sub_nonrefs	_jc_java_beans_Expression$sub_nonrefs;
typedef struct _jc_java_beans_Expression$refs	_jc_java_beans_Expression$refs;
typedef struct _jc_java_beans_Expression$nonrefs	_jc_java_beans_Expression$nonrefs;
typedef struct _jc_java_beans_Expression$object	_jc_java_beans_Expression$object;

typedef struct _jc_java_beans_Expression$fields_struct	_jc_java_beans_Expression$fields_struct;
typedef const struct _jc_java_beans_Expression$vmethods	_jc_java_beans_Expression$vmethods;
typedef const struct _jc_java_beans_Expression$vtable	_jc_java_beans_Expression$vtable;
typedef const struct _jc_java_beans_Expression$vtype	_jc_java_beans_Expression$vtype;

// Class fields structure
struct _jc_java_beans_Expression$fields_struct {
	struct _jc_java_lang_Object$object	*unset;
};
extern _jc_java_beans_Expression$fields_struct _jc_java_beans_Expression$class_fields;

// Constructors
extern void _jc_java_beans_Expression$method$_init$9de4a9a3842aff31(_jc_env *, struct _jc_java_beans_Expression$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_String$object *, struct _jc_object_array *);
extern void _jc_java_beans_Expression$method$_init$a203813a6d0e9e38(_jc_env *, struct _jc_java_beans_Expression$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_String$object *, struct _jc_object_array *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_beans_Expression$method$getValue$6f8b281a5ffcc94f(_jc_env *, struct _jc_java_beans_Expression$object *);
extern void _jc_java_beans_Expression$method$setValue$6db444395631b4fe(_jc_env *, struct _jc_java_beans_Expression$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_String$object *_jc_java_beans_Expression$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_beans_Expression$object *);

// Virtual method descriptors
extern _jc_method _jc_java_beans_Expression$method_info$getValue$6f8b281a5ffcc94f;
extern _jc_method _jc_java_beans_Expression$method_info$setValue$6db444395631b4fe;
extern _jc_method _jc_java_beans_Expression$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_java_beans_Expression$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_beans_Expression$vmethods {
	struct _jc_java_lang_Object$object	*(*getValue$6f8b281a5ffcc94f)(_jc_env *, struct _jc_java_beans_Expression$object *);
	void	(*setValue$6db444395631b4fe)(_jc_env *, struct _jc_java_beans_Expression$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_beans_Expression$object *);
};

// Vtable
struct _jc_java_beans_Expression$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_Statement$vmethods	java_beans_Statement;
	_jc_java_beans_Expression$vmethods	java_beans_Expression;
};

// Vtype
struct _jc_java_beans_Expression$vtype {
	_jc_type			type;
	_jc_java_beans_Expression$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_Expression$sub_refs {
	struct _jc_java_lang_Object$object	*value;
};

// Reference instance fields (object)
struct _jc_java_beans_Expression$refs {
    _jc_java_beans_Expression$sub_refs	java_beans_Expression;
    _jc_java_beans_Statement$sub_refs	java_beans_Statement;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_Expression$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_Expression$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_Statement$sub_nonrefs	java_beans_Statement;
    _jc_java_beans_Expression$sub_nonrefs	java_beans_Expression;
};

// Object instance structure
struct _jc_java_beans_Expression$object {
	_jc_java_beans_Expression$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_Expression$vtype	*vtype;
	_jc_java_beans_Expression$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_Expression$vtype _jc_java_beans_Expression$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_Expression, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_Expression$class_object;

#endif	/* _JC_java_beans_Expression_H_ */

==> jc-1.4.6.tar.gz: java/beans/Expression.h <==
// public class java.beans.Expression

// class file dependencies
// @dep_class 3e0727273db17f2 java_beans_Expression
// @dep_class 98ab29a738188935 java_beans_Statement
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_beans_Statement

#include "java/beans/Statement.h"

#ifndef _JC_java_beans_Expression_H_
#define _JC_java_beans_Expression_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_beans_Expression$sub_refs	_jc_java_beans_Expression$sub_refs;
typedef struct _jc_java_beans_Expression$sub_nonrefs	_jc_java_beans_Expression$sub_nonrefs;
typedef struct _jc_java_beans_Expression$refs	_jc_java_beans_Expression$refs;
typedef struct _jc_java_beans_Expression$nonrefs	_jc_java_beans_Expression$nonrefs;
typedef struct _jc_java_beans_Expression$object	_jc_java_beans_Expression$object;

typedef struct _jc_java_beans_Expression$fields_struct	_jc_java_beans_Expression$fields_struct;
typedef const struct _jc_java_beans_Expression$vmethods	_jc_java_beans_Expression$vmethods;
typedef const struct _jc_java_beans_Expression$vtable	_jc_java_beans_Expression$vtable;
typedef const struct _jc_java_beans_Expression$vtype	_jc_java_beans_Expression$vtype;

// Class fields structure
struct _jc_java_beans_Expression$fields_struct {
	struct _jc_java_lang_Object$object	*unset;
};
extern _jc_java_beans_Expression$fields_struct _jc_java_beans_Expression$class_fields;

// Constructors
extern void _jc_java_beans_Expression$method$_init$9de4a9a3842aff31(_jc_env *, struct _jc_java_beans_Expression$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_String$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern void _jc_java_beans_Expression$method$_init$a203813a6d0e9e38(_jc_env *, struct _jc_java_beans_Expression$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_String$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_beans_Expression$method$getValue$6f8b281a5ffcc94f(_jc_env *, struct _jc_java_beans_Expression$object *) _JC_JCNI_ATTR;
extern void _jc_java_beans_Expression$method$setValue$6db444395631b4fe(_jc_env *, struct _jc_java_beans_Expression$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_beans_Expression$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_beans_Expression$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_beans_Expression$method_info$getValue$6f8b281a5ffcc94f;
extern _jc_method _jc_java_beans_Expression$method_info$setValue$6db444395631b4fe;
extern _jc_method _jc_java_beans_Expression$method_info$toString$7ea43b33b80a3070;

// Static methods
extern void _jc_java_beans_Expression$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_beans_Expression$vmethods {
	struct _jc_java_lang_Object$object	*(*getValue$6f8b281a5ffcc94f)(_jc_env *, struct _jc_java_beans_Expression$object *) _JC_JCNI_ATTR;
	void	(*setValue$6db444395631b4fe)(_jc_env *, struct _jc_java_beans_Expression$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_beans_Expression$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_beans_Expression$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_Statement$vmethods	java_beans_Statement;
	_jc_java_beans_Expression$vmethods	java_beans_Expression;
};

// Vtype
struct _jc_java_beans_Expression$vtype {
	_jc_type			type;
	_jc_java_beans_Expression$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_Expression$sub_refs {
	struct _jc_java_lang_Object$object	*value;
};

// Reference instance fields (object)
struct _jc_java_beans_Expression$refs {
    _jc_java_beans_Expression$sub_refs	java_beans_Expression;
    _jc_java_beans_Statement$sub_refs	java_beans_Statement;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_Expression$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_Expression$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_Statement$sub_nonrefs	java_beans_Statement;
    _jc_java_beans_Expression$sub_nonrefs	java_beans_Expression;
};

// Object instance structure
struct _jc_java_beans_Expression$object {
	_jc_java_beans_Expression$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_Expression$vtype	*vtype;
	_jc_java_beans_Expression$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_Expression$vtype _jc_java_beans_Expression$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_Expression, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_Expression$class_object;

#endif	/* _JC_java_beans_Expression_H_ */
